==> ejc-budgetmanage-impl-3.0.0-20220325.144208-24-sources.jar: com/ejianc/business/record/bean/RecordsubpackagematerialanalysisEntity.java <==
package com.ejianc.business.record.bean;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 分包施工图预算材料分析变更记录
 * 
 * @author generator
 * 
 */
 @TableName("ejc_record_budgetmanage_subpackagematerialanalysis")
public class RecordsubpackagematerialanalysisEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_code")
    private java.lang.String billCode; // 单据编号
    @TableField(value="original_id")
    private java.lang.Long originalId; // 原始单据id
    @TableField(value="project_id")
    private java.lang.Long projectId; // 项目id
    @TableField(value="project_name")
    private java.lang.String projectName; // 项目名称
    @TableField(value="change_state")
    private java.lang.String changeState; // 变更状态
    @TableField(value="change_reason")
    private java.lang.String changeReason; // 变更原因
    @TableField(value="effect_date")
    private java.util.Date effectDate; // 生效时间
    @TableField(value="contract_id")
    private java.lang.Long contractId; // 合同id
    @TableField(value="contract_name")
    private java.lang.String contractName; // 合同名称
    @TableField(value="bill_State")
    private java.lang.Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    @TableField(value="subpackagematerialanalysis_code")
    private java.lang.String subpackagematerialanalysisCode; // 变更单据

    @TableField(exist=false)
    @SubEntity(serviceName="ecordsubpackmateanalydetailService", pidName = "mid")
    private List<RecordsubpackmateanalydetailEntity> subpackagematerialanalysisdetailEntites = new ArrayList<>(); // 分包施工图预算材料分析变更记录子表
    /**
     * 单据编号
     */
    public java.lang.String getBillCode() {
        return billCode;
    }

    /**
     * 单据编号
     */
    public void setBillCode(java.lang.String billCode) {
        this.billCode = billCode;
    }
    /**
     * 原始单据id
     */
    public java.lang.Long getOriginalId() {
        return originalId;
    }

    /**
     * 原始单据id
     */
    public void setOriginalId(java.lang.Long originalId) {
        this.originalId = originalId;
    }
    /**
     * 项目id
     */
    public java.lang.Long getProjectId() {
        return projectId;
    }

    /**
     * 项目id
     */
    public void setProjectId(java.lang.Long projectId) {
        this.projectId = projectId;
    }
    /**
     * 项目名称
     */
    public java.lang.String getProjectName() {
        return projectName;
    }

    /**
     * 项目名称
     */
    public void setProjectName(java.lang.String projectName) {
        this.projectName = projectName;
    }
    /**
     * 变更状态
     */
    public java.lang.String getChangeState() {
        return changeState;
    }

    /**
     * 变更状态
     */
    public void setChangeState(java.lang.String changeState) {
        this.changeState = changeState;
    }
    /**
     * 变更原因
     */
    public java.lang.String getChangeReason() {
        return changeReason;
    }

    /**
     * 变更原因
     */
    public void setChangeReason(java.lang.String changeReason) {
        this.changeReason = changeReason;
    }
    /**
     * 生效时间
     */
    public java.util.Date getEffectDate() {
        return effectDate;
    }

    /**
     * 生效时间
     */
    public void setEffectDate(java.util.Date effectDate) {
        this.effectDate = effectDate;
    }
    /**
     * 合同id
     */
    public java.lang.Long getContractId() {
        return contractId;
    }

    /**
     * 合同id
     */
    public void setContractId(java.lang.Long contractId) {
        this.contractId = contractId;
    }
    /**
     * 合同名称
     */
    public java.lang.String getContractName() {
        return contractName;
    }

    /**
     * 合同名称
     */
    public void setContractName(java.lang.String contractName) {
        this.contractName = contractName;
    }

    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }

    /**
     * 分包施工图预算材料分析变更记录子表
     */
    public List<RecordsubpackmateanalydetailEntity> getSubpackagematerialanalysisdetailEntites() {
        return subpackagematerialanalysisdetailEntites;
    }

    /**
     * 分包施工图预算材料分析变更记录子表
     */
    public void setSubpackagematerialanalysisdetailEntites(List<RecordsubpackmateanalydetailEntity> subpackagematerialanalysisdetailEntites) {
        this.subpackagematerialanalysisdetailEntites = subpackagematerialanalysisdetailEntites;
    }




    public String getSubpackagematerialanalysisCode() {
        return subpackagematerialanalysisCode;
    }

    public void setSubpackagematerialanalysisCode(String subpackagematerialanalysisCode) {
        this.subpackagematerialanalysisCode = subpackagematerialanalysisCode;
    }
}

==> ejc-budgetmanage-impl-3.0.0-20220406.092419-64-sources.jar: com/ejianc/business/record/bean/RecordsubpackagematerialanalysisEntity.java <==
package com.ejianc.business.record.bean;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 分包施工图预算材料分析变更记录
 * 
 * @author generator
 * 
 */
 @TableName("ejc_record_budgetmanage_subpackagematerialanalysis")
public class RecordsubpackagematerialanalysisEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_code")
    private java.lang.String billCode; // 单据编号
    @TableField(value="original_id")
    private java.lang.Long originalId; // 原始单据id
    @TableField(value="project_id")
    private java.lang.Long projectId; // 项目id
    @TableField(value="project_name")
    private java.lang.String projectName; // 项目名称
    @TableField(value="change_state")
    private java.lang.String changeState; // 变更状态
    @TableField(value="change_reason")
    private java.lang.String changeReason; // 变更原因
    @TableField(value="effect_date")
    private java.util.Date effectDate; // 生效时间
    @TableField(value="contract_id")
    private java.lang.Long contractId; // 合同id
    @TableField(value="contract_name")
    private java.lang.String contractName; // 合同名称
    @TableField(value="bill_State")
    private java.lang.Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    @TableField(value="subpackagematerialanalysis_code")
    private java.lang.String subpackagematerialanalysisCode; // 变更单据
    @TableField(value="total")
    private java.lang.Double total;//合计汇总数量

    @TableField(exist=false)
    @SubEntity(serviceName="ecordsubpackmateanalydetailService", pidName = "mid")
    private List<RecordsubpackmateanalydetailEntity> subpackagematerialanalysisdetailEntites = new ArrayList<>(); // 分包施工图预算材料分析变更记录子表
    /**
     * 单据编号
     */
    public java.lang.String getBillCode() {
        return billCode;
    }

    /**
     * 单据编号
     */
    public void setBillCode(java.lang.String billCode) {
        this.billCode = billCode;
    }
    /**
     * 原始单据id
     */
    public java.lang.Long getOriginalId() {
        return originalId;
    }

    /**
     * 原始单据id
     */
    public void setOriginalId(java.lang.Long originalId) {
        this.originalId = originalId;
    }
    /**
     * 项目id
     */
    public java.lang.Long getProjectId() {
        return projectId;
    }

    /**
     * 项目id
     */
    public void setProjectId(java.lang.Long projectId) {
        this.projectId = projectId;
    }
    /**
     * 项目名称
     */
    public java.lang.String getProjectName() {
        return projectName;
    }

    /**
     * 项目名称
     */
    public void setProjectName(java.lang.String projectName) {
        this.projectName = projectName;
    }
    /**
     * 变更状态
     */
    public java.lang.String getChangeState() {
        return changeState;
    }

    /**
     * 变更状态
     */
    public void setChangeState(java.lang.String changeState) {
        this.changeState = changeState;
    }
    /**
     * 变更原因
     */
    public java.lang.String getChangeReason() {
        return changeReason;
    }

    /**
     * 变更原因
     */
    public void setChangeReason(java.lang.String changeReason) {
        this.changeReason = changeReason;
    }
    /**
     * 生效时间
     */
    public java.util.Date getEffectDate() {
        return effectDate;
    }

    /**
     * 生效时间
     */
    public void setEffectDate(java.util.Date effectDate) {
        this.effectDate = effectDate;
    }
    /**
     * 合同id
     */
    public java.lang.Long getContractId() {
        return contractId;
    }

    /**
     * 合同id
     */
    public void setContractId(java.lang.Long contractId) {
        this.contractId = contractId;
    }
    /**
     * 合同名称
     */
    public java.lang.String getContractName() {
        return contractName;
    }

    /**
     * 合同名称
     */
    public void setContractName(java.lang.String contractName) {
        this.contractName = contractName;
    }

    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }

    /**
     * 分包施工图预算材料分析变更记录子表
     */
    public List<RecordsubpackmateanalydetailEntity> getSubpackagematerialanalysisdetailEntites() {
        return subpackagematerialanalysisdetailEntites;
    }

    /**
     * 分包施工图预算材料分析变更记录子表
     */
    public void setSubpackagematerialanalysisdetailEntites(List<RecordsubpackmateanalydetailEntity> subpackagematerialanalysisdetailEntites) {
        this.subpackagematerialanalysisdetailEntites = subpackagematerialanalysisdetailEntites;
    }




    public String getSubpackagematerialanalysisCode() {
        return subpackagematerialanalysisCode;
    }

    public void setSubpackagematerialanalysisCode(String subpackagematerialanalysisCode) {
        this.subpackagematerialanalysisCode = subpackagematerialanalysisCode;
    }

    public Double getTotal() {
        return total;
    }

    public void setTotal(Double total) {
        this.total = total;
    }
}
